@@ -18,14 +18,13 @@ from typing import IO, Any, Dict, List, Type, Union, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_iotanalytics.paginator import (
+from .paginator import (
     ListChannelsPaginator,
     ListDatasetContentsPaginator,
     ListDatasetsPaginator,
     ListDatastoresPaginator,
     ListPipelinesPaginator,
 )
-
 from .type_defs import (
     BatchPutMessageResponseTypeDef,
     ChannelMessagesTypeDef,
@@ -94,7 +93,7 @@ class Exceptions:
 
 class IoTAnalyticsClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -105,22 +104,22 @@ class IoTAnalyticsClient:
         self, channelName: str, messages: List[MessageTypeDef]
     ) -> BatchPutMessageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.batch_put_message)
-        [Show boto3-stubs documentation](./client.md#batch-put-message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.batch_put_message)
+        [Show boto3-stubs documentation](./client.md#batch_put_message)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def cancel_pipeline_reprocessing(
         self, pipelineName: str, reprocessingId: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.cancel_pipeline_reprocessing)
-        [Show boto3-stubs documentation](./client.md#cancel-pipeline-reprocessing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.cancel_pipeline_reprocessing)
+        [Show boto3-stubs documentation](./client.md#cancel_pipeline_reprocessing)
         """
 
     def create_channel(
@@ -131,8 +130,8 @@ class IoTAnalyticsClient:
         tags: List["TagTypeDef"] = None,
     ) -> CreateChannelResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.create_channel)
-        [Show boto3-stubs documentation](./client.md#create-channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.create_channel)
+        [Show boto3-stubs documentation](./client.md#create_channel)
         """
 
     def create_dataset(
@@ -147,16 +146,16 @@ class IoTAnalyticsClient:
         lateDataRules: List["LateDataRuleTypeDef"] = None,
     ) -> CreateDatasetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset)
-        [Show boto3-stubs documentation](./client.md#create-dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset)
+        [Show boto3-stubs documentation](./client.md#create_dataset)
         """
 
     def create_dataset_content(
         self, datasetName: str, versionId: str = None
     ) -> CreateDatasetContentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset_content)
-        [Show boto3-stubs documentation](./client.md#create-dataset-content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset_content)
+        [Show boto3-stubs documentation](./client.md#create_dataset_content)
         """
 
     def create_datastore(
@@ -168,8 +167,8 @@ class IoTAnalyticsClient:
         fileFormatConfiguration: "FileFormatConfigurationTypeDef" = None,
     ) -> CreateDatastoreResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.create_datastore)
-        [Show boto3-stubs documentation](./client.md#create-datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.create_datastore)
+        [Show boto3-stubs documentation](./client.md#create_datastore)
         """
 
     def create_pipeline(
@@ -179,72 +178,72 @@ class IoTAnalyticsClient:
         tags: List["TagTypeDef"] = None,
     ) -> CreatePipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.create_pipeline)
-        [Show boto3-stubs documentation](./client.md#create-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.create_pipeline)
+        [Show boto3-stubs documentation](./client.md#create_pipeline)
         """
 
     def delete_channel(self, channelName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_channel)
-        [Show boto3-stubs documentation](./client.md#delete-channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_channel)
+        [Show boto3-stubs documentation](./client.md#delete_channel)
         """
 
     def delete_dataset(self, datasetName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset)
-        [Show boto3-stubs documentation](./client.md#delete-dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset)
+        [Show boto3-stubs documentation](./client.md#delete_dataset)
         """
 
     def delete_dataset_content(self, datasetName: str, versionId: str = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset_content)
-        [Show boto3-stubs documentation](./client.md#delete-dataset-content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset_content)
+        [Show boto3-stubs documentation](./client.md#delete_dataset_content)
         """
 
     def delete_datastore(self, datastoreName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_datastore)
-        [Show boto3-stubs documentation](./client.md#delete-datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_datastore)
+        [Show boto3-stubs documentation](./client.md#delete_datastore)
         """
 
     def delete_pipeline(self, pipelineName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_pipeline)
-        [Show boto3-stubs documentation](./client.md#delete-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_pipeline)
+        [Show boto3-stubs documentation](./client.md#delete_pipeline)
         """
 
     def describe_channel(
         self, channelName: str, includeStatistics: bool = None
     ) -> DescribeChannelResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_channel)
-        [Show boto3-stubs documentation](./client.md#describe-channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_channel)
+        [Show boto3-stubs documentation](./client.md#describe_channel)
         """
 
     def describe_dataset(self, datasetName: str) -> DescribeDatasetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_dataset)
-        [Show boto3-stubs documentation](./client.md#describe-dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_dataset)
+        [Show boto3-stubs documentation](./client.md#describe_dataset)
         """
 
     def describe_datastore(
         self, datastoreName: str, includeStatistics: bool = None
     ) -> DescribeDatastoreResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_datastore)
-        [Show boto3-stubs documentation](./client.md#describe-datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_datastore)
+        [Show boto3-stubs documentation](./client.md#describe_datastore)
         """
 
     def describe_logging_options(self) -> DescribeLoggingOptionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_logging_options)
-        [Show boto3-stubs documentation](./client.md#describe-logging-options)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_logging_options)
+        [Show boto3-stubs documentation](./client.md#describe_logging_options)
         """
 
     def describe_pipeline(self, pipelineName: str) -> DescribePipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_pipeline)
-        [Show boto3-stubs documentation](./client.md#describe-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_pipeline)
+        [Show boto3-stubs documentation](./client.md#describe_pipeline)
         """
 
     def generate_presigned_url(
@@ -255,24 +254,24 @@ class IoTAnalyticsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_dataset_content(
         self, datasetName: str, versionId: str = None
     ) -> GetDatasetContentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.get_dataset_content)
-        [Show boto3-stubs documentation](./client.md#get-dataset-content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.get_dataset_content)
+        [Show boto3-stubs documentation](./client.md#get_dataset_content)
         """
 
     def list_channels(
         self, nextToken: str = None, maxResults: int = None
     ) -> ListChannelsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.list_channels)
-        [Show boto3-stubs documentation](./client.md#list-channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.list_channels)
+        [Show boto3-stubs documentation](./client.md#list_channels)
         """
 
     def list_dataset_contents(
@@ -284,52 +283,52 @@ class IoTAnalyticsClient:
         scheduledBefore: datetime = None,
     ) -> ListDatasetContentsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.list_dataset_contents)
-        [Show boto3-stubs documentation](./client.md#list-dataset-contents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.list_dataset_contents)
+        [Show boto3-stubs documentation](./client.md#list_dataset_contents)
         """
 
     def list_datasets(
         self, nextToken: str = None, maxResults: int = None
     ) -> ListDatasetsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datasets)
-        [Show boto3-stubs documentation](./client.md#list-datasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datasets)
+        [Show boto3-stubs documentation](./client.md#list_datasets)
         """
 
     def list_datastores(
         self, nextToken: str = None, maxResults: int = None
     ) -> ListDatastoresResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datastores)
-        [Show boto3-stubs documentation](./client.md#list-datastores)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datastores)
+        [Show boto3-stubs documentation](./client.md#list_datastores)
         """
 
     def list_pipelines(
         self, nextToken: str = None, maxResults: int = None
     ) -> ListPipelinesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.list_pipelines)
-        [Show boto3-stubs documentation](./client.md#list-pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.list_pipelines)
+        [Show boto3-stubs documentation](./client.md#list_pipelines)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def put_logging_options(self, loggingOptions: "LoggingOptionsTypeDef") -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.put_logging_options)
-        [Show boto3-stubs documentation](./client.md#put-logging-options)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.put_logging_options)
+        [Show boto3-stubs documentation](./client.md#put_logging_options)
         """
 
     def run_pipeline_activity(
         self, pipelineActivity: "PipelineActivityTypeDef", payloads: List[Union[bytes, IO[bytes]]]
     ) -> RunPipelineActivityResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.run_pipeline_activity)
-        [Show boto3-stubs documentation](./client.md#run-pipeline-activity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.run_pipeline_activity)
+        [Show boto3-stubs documentation](./client.md#run_pipeline_activity)
         """
 
     def sample_channel_data(
@@ -340,8 +339,8 @@ class IoTAnalyticsClient:
         endTime: datetime = None,
     ) -> SampleChannelDataResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.sample_channel_data)
-        [Show boto3-stubs documentation](./client.md#sample-channel-data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.sample_channel_data)
+        [Show boto3-stubs documentation](./client.md#sample_channel_data)
         """
 
     def start_pipeline_reprocessing(
@@ -352,20 +351,20 @@ class IoTAnalyticsClient:
         channelMessages: ChannelMessagesTypeDef = None,
     ) -> StartPipelineReprocessingResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.start_pipeline_reprocessing)
-        [Show boto3-stubs documentation](./client.md#start-pipeline-reprocessing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.start_pipeline_reprocessing)
+        [Show boto3-stubs documentation](./client.md#start_pipeline_reprocessing)
         """
 
     def tag_resource(self, resourceArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_channel(
@@ -375,8 +374,8 @@ class IoTAnalyticsClient:
         retentionPeriod: "RetentionPeriodTypeDef" = None,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.update_channel)
-        [Show boto3-stubs documentation](./client.md#update-channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.update_channel)
+        [Show boto3-stubs documentation](./client.md#update_channel)
         """
 
     def update_dataset(
@@ -390,8 +389,8 @@ class IoTAnalyticsClient:
         lateDataRules: List["LateDataRuleTypeDef"] = None,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.update_dataset)
-        [Show boto3-stubs documentation](./client.md#update-dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.update_dataset)
+        [Show boto3-stubs documentation](./client.md#update_dataset)
         """
 
     def update_datastore(
@@ -402,22 +401,22 @@ class IoTAnalyticsClient:
         fileFormatConfiguration: "FileFormatConfigurationTypeDef" = None,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.update_datastore)
-        [Show boto3-stubs documentation](./client.md#update-datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.update_datastore)
+        [Show boto3-stubs documentation](./client.md#update_datastore)
         """
 
     def update_pipeline(
         self, pipelineName: str, pipelineActivities: List["PipelineActivityTypeDef"]
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Client.update_pipeline)
-        [Show boto3-stubs documentation](./client.md#update-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Client.update_pipeline)
+        [Show boto3-stubs documentation](./client.md#update_pipeline)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_channels"]) -> ListChannelsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels)[Show boto3-stubs documentation](./paginators.md#listchannelspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels)[Show boto3-stubs documentation](./paginators.md#listchannelspaginator)
         """
 
     @overload
@@ -425,23 +424,23 @@ class IoTAnalyticsClient:
         self, operation_name: Literal["list_dataset_contents"]
     ) -> ListDatasetContentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents)[Show boto3-stubs documentation](./paginators.md#listdatasetcontentspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents)[Show boto3-stubs documentation](./paginators.md#listdatasetcontentspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets)[Show boto3-stubs documentation](./paginators.md#listdatasetspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets)[Show boto3-stubs documentation](./paginators.md#listdatasetspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datastores"]) -> ListDatastoresPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores)[Show boto3-stubs documentation](./paginators.md#listdatastorespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores)[Show boto3-stubs documentation](./paginators.md#listdatastorespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines)[Show boto3-stubs documentation](./paginators.md#listpipelinespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines)[Show boto3-stubs documentation](./paginators.md#listpipelinespaginator)
         """
